"""
Generated class for Evidence. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class VariableDefinition(FhirBaseModel):
    """Evidence variable such as population, exposure, or outcome.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: A text description or summary of the variable
    :param Annotation note: Footnotes and/or explanatory notes
    :param CodeableConcept variableRole: population | subpopulation | exposure | referenceExposure | measuredVariable | confounder
    :param Reference observed: Definition of the actual variable related to the statistic(s)
    :param Reference intended: Definition of the intended variable related to the Evidence
    :param CodeableConcept directnessMatch: low | moderate | high | exact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "variableRole": {"class_name": "CodeableConcept", "is_contained": False},
        "observed": {"class_name": "Reference", "is_contained": False},
        "intended": {"class_name": "Reference", "is_contained": False},
        "directnessMatch": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        variableRole: "CodeableConcept" = None,
        observed: "Reference" = None,
        intended: "Reference" = None,
        directnessMatch: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.note = note or []
        self.variableRole = variableRole
        self.observed = observed
        self.intended = intended
        self.directnessMatch = directnessMatch

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SampleSize(FhirBaseModel):
    """Number of samples in the statistic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Textual description of sample size for statistic
    :param Annotation note: Footnote or explanatory note about the sample size
    :param int numberOfStudies: Number of contributing studies
    :param int numberOfParticipants: Cumulative number of participants
    :param int knownDataCount: Number of participants with known results for measured variables
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        numberOfStudies: "int" = None,
        numberOfParticipants: "int" = None,
        knownDataCount: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.note = note or []
        self.numberOfStudies = numberOfStudies
        self.numberOfParticipants = numberOfParticipants
        self.knownDataCount = knownDataCount

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AttributeEstimate(FhirBaseModel):
    """A statistical attribute of the statistic such as a measure of heterogeneity.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Textual description of the attribute estimate
    :param Annotation note: Footnote or explanatory note about the estimate
    :param CodeableConcept type: The type of attribute estimate, e.g., confidence interval or p value
    :param Quantity quantity: The singular quantity of the attribute estimate, for attribute estimates represented as single values; also used to report unit of measure
    :param float level: Level of confidence interval, e.g., 0.95 for 95% confidence interval
    :param Range range: Lower and upper bound values of the attribute estimate
    :param AttributeEstimate attributeEstimate: A nested attribute estimate; which is the attribute estimate of an attribute estimate
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "range": {"class_name": "Range", "is_contained": False},
        "attributeEstimate": {"class_name": "AttributeEstimate", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        type: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        level: "float" = None,
        range: "Range" = None,
        attributeEstimate: list["AttributeEstimate"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.note = note or []
        self.type = type
        self.quantity = quantity
        self.level = level
        self.range = range
        self.attributeEstimate = attributeEstimate or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Variable(FhirBaseModel):
    """A variable adjusted for in the adjusted analysis.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference variableDefinition: Description of the variable
    :param str handling: continuous | dichotomous | ordinal | polychotomous
    :param CodeableConcept valueCategory: Description for grouping of ordinal or polychotomous variables
    :param Quantity valueQuantity: Discrete value for grouping of ordinal or polychotomous variables
    :param Range valueRange: Range of values for grouping of ordinal or polychotomous variables
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "variableDefinition": {"class_name": "Reference", "is_contained": False},
        "valueCategory": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        variableDefinition: "Reference" = None,
        handling: "str" = None,
        valueCategory: list["CodeableConcept"] = None,
        valueQuantity: list["Quantity"] = None,
        valueRange: list["Range"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.variableDefinition = variableDefinition
        self.handling = handling
        self.valueCategory = valueCategory or []
        self.valueQuantity = valueQuantity or []
        self.valueRange = valueRange or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ModelCharacteristic(FhirBaseModel):
    """A component of the method to generate the statistic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Model specification
    :param Quantity value: Numerical value to complete model specification
    :param Variable variable: A variable adjusted for in the adjusted analysis
    :param AttributeEstimate attributeEstimate: An attribute of the statistic used as a model characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "value": {"class_name": "Quantity", "is_contained": False},
        "variable": {"class_name": "Variable", "is_contained": True},
        "attributeEstimate": {"class_name": "AttributeEstimate", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        value: "Quantity" = None,
        variable: list["Variable"] = None,
        attributeEstimate: list["AttributeEstimate"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.value = value
        self.variable = variable or []
        self.attributeEstimate = attributeEstimate or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Statistic(FhirBaseModel):
    """Values and parameters for a single statistic.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of content
    :param Annotation note: Footnotes and/or explanatory notes
    :param CodeableConcept statisticType: Type of statistic, e.g., relative risk
    :param CodeableConcept category: Associated category for categorical variable
    :param Quantity quantity: Statistic value
    :param int numberOfEvents: The number of events associated with the statistic
    :param int numberAffected: The number of participants affected
    :param SampleSize sampleSize: Number of samples in the statistic
    :param AttributeEstimate attributeEstimate: An attribute of the Statistic
    :param ModelCharacteristic modelCharacteristic: An aspect of the statistical model
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "statisticType": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "sampleSize": {"class_name": "SampleSize", "is_contained": True},
        "attributeEstimate": {"class_name": "AttributeEstimate", "is_contained": True},
        "modelCharacteristic": {
            "class_name": "ModelCharacteristic",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        statisticType: "CodeableConcept" = None,
        category: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        numberOfEvents: "int" = None,
        numberAffected: "int" = None,
        sampleSize: "SampleSize" = None,
        attributeEstimate: list["AttributeEstimate"] = None,
        modelCharacteristic: list["ModelCharacteristic"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.note = note or []
        self.statisticType = statisticType
        self.category = category
        self.quantity = quantity
        self.numberOfEvents = numberOfEvents
        self.numberAffected = numberAffected
        self.sampleSize = sampleSize
        self.attributeEstimate = attributeEstimate or []
        self.modelCharacteristic = modelCharacteristic or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Certainty(FhirBaseModel):
    """Assessment of certainty, confidence in the estimates, or quality of the evidence.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Textual description of certainty
    :param Annotation note: Footnotes and/or explanatory notes
    :param CodeableConcept type: Aspect of certainty being rated
    :param CodeableConcept rating: Assessment or judgement of the aspect
    :param str rater: Individual or group who did the rating
    :param Subcomponent subcomponent: A domain or subdomain of certainty
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "rating": {"class_name": "CodeableConcept", "is_contained": False},
        "subcomponent": {"class_name": "Subcomponent", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        type: "CodeableConcept" = None,
        rating: "CodeableConcept" = None,
        rater: "str" = None,
        subcomponent: list["Subcomponent"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.note = note or []
        self.type = type
        self.rating = rating
        self.rater = rater
        self.subcomponent = subcomponent or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Evidence(DomainResource):
    """The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (e.g., population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this evidence, represented as a globally unique URI
    :param Identifier identifier: Additional identifier for the summary
    :param str version: Business version of this summary
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this summary (machine friendly)
    :param str title: Name for this summary (human friendly)
    :param Reference citeAsReference: Citation for this evidence
    :param str citeAsMarkdown: Citation for this evidence
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str approvalDate: When the summary was approved by publisher
    :param str lastReviewDate: When the summary was last reviewed by the publisher
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param UsageContext useContext: The context that the content is intended to support
    :param str purpose: Why this Evidence is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param RelatedArtifact relatedArtifact: Link or citation to artifact associated with the summary
    :param str description: Description of the particular summary
    :param str assertion: Declarative description of the Evidence
    :param Annotation note: Footnotes and/or explanatory notes
    :param VariableDefinition variableDefinition: Evidence variable such as population, exposure, or outcome
    :param CodeableConcept synthesisType: The method to combine studies
    :param CodeableConcept studyDesign: The design of the study that produced this evidence
    :param Statistic statistic: Values and parameters for a single statistic
    :param Certainty certainty: Certainty or quality of the evidence
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "citeAsReference": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "variableDefinition": {
            "class_name": "VariableDefinition",
            "is_contained": True,
        },
        "synthesisType": {"class_name": "CodeableConcept", "is_contained": False},
        "studyDesign": {"class_name": "CodeableConcept", "is_contained": False},
        "statistic": {"class_name": "Statistic", "is_contained": True},
        "certainty": {"class_name": "Certainty", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        citeAsReference: "Reference" = None,
        citeAsMarkdown: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        useContext: list["UsageContext"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        description: "str" = None,
        assertion: "str" = None,
        note: list["Annotation"] = None,
        variableDefinition: list["VariableDefinition"] = None,
        synthesisType: "CodeableConcept" = None,
        studyDesign: list["CodeableConcept"] = None,
        statistic: list["Statistic"] = None,
        certainty: list["Certainty"] = None,
    ):

        self.resourceType = "Evidence"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.citeAsReference = citeAsReference
        self.citeAsMarkdown = citeAsMarkdown
        self.status = status
        self.experimental = experimental
        self.date = date
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.publisher = publisher
        self.contact = contact or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.useContext = useContext or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.relatedArtifact = relatedArtifact or []
        self.description = description
        self.assertion = assertion
        self.note = note or []
        self.variableDefinition = variableDefinition or []
        self.synthesisType = synthesisType
        self.studyDesign = studyDesign or []
        self.statistic = statistic or []
        self.certainty = certainty or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Immunization. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Performer(FhirBaseModel):
    """Indicates who performed the immunization event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: What type of performance was done
    :param Reference actor: Individual or organization who was performing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Immunization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Immunization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Education(FhirBaseModel):
    """Educational material presented to the patient (or guardian) at the time of vaccine administration.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str documentType: Educational material document identifier
    :param str reference: Educational material reference pointer
    :param str publicationDate: Educational material publication date
    :param str presentationDate: Educational material presentation date
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        documentType: "str" = None,
        reference: "str" = None,
        publicationDate: "str" = None,
        presentationDate: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.documentType = documentType
        self.reference = reference
        self.publicationDate = publicationDate
        self.presentationDate = presentationDate

    @classmethod
    def from_dict(cls, data: dict) -> "Immunization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Immunization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Reaction(FhirBaseModel):
    """Categorical data indicating that an adverse event is associated in time to an immunization.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str date: When reaction started
    :param Reference detail: Additional information on reaction
    :param bool reported: Indicates self-reported reaction
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "detail": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        date: "str" = None,
        detail: "Reference" = None,
        reported: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.date = date
        self.detail = detail
        self.reported = reported

    @classmethod
    def from_dict(cls, data: dict) -> "Immunization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Immunization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProtocolApplied(FhirBaseModel):
    """The protocol (set of recommendations) being followed by the provider who administered the dose.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str series: Name of vaccine series
    :param Reference authority: Who is responsible for publishing the recommendations
    :param CodeableConcept targetDisease: Vaccine preventatable disease being targetted
    :param int doseNumberPositiveInt: Dose number within series
    :param str doseNumberString: Dose number within series
    :param int seriesDosesPositiveInt: Recommended number of doses for immunity
    :param str seriesDosesString: Recommended number of doses for immunity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "authority": {"class_name": "Reference", "is_contained": False},
        "targetDisease": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        series: "str" = None,
        authority: "Reference" = None,
        targetDisease: list["CodeableConcept"] = None,
        doseNumberPositiveInt: "int" = None,
        doseNumberString: "str" = None,
        seriesDosesPositiveInt: "int" = None,
        seriesDosesString: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.series = series
        self.authority = authority
        self.targetDisease = targetDisease or []
        self.doseNumberPositiveInt = doseNumberPositiveInt
        self.doseNumberString = doseNumberString
        self.seriesDosesPositiveInt = seriesDosesPositiveInt
        self.seriesDosesString = seriesDosesString

    @classmethod
    def from_dict(cls, data: dict) -> "Immunization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Immunization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Immunization(DomainResource):
    """Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier
    :param str status: completed | entered-in-error | not-done
    :param CodeableConcept statusReason: Reason not done
    :param CodeableConcept vaccineCode: Vaccine product administered
    :param Reference patient: Who was immunized
    :param Reference encounter: Encounter immunization was part of
    :param str occurrenceDateTime: Vaccine administration date
    :param str occurrenceString: Vaccine administration date
    :param str recorded: When the immunization was first captured in the subject's record
    :param bool primarySource: Indicates context the data was recorded in
    :param CodeableConcept reportOrigin: Indicates the source of a secondarily reported record
    :param Reference location: Where immunization occurred
    :param Reference manufacturer: Vaccine manufacturer
    :param str lotNumber: Vaccine lot number
    :param str expirationDate: Vaccine expiration date
    :param CodeableConcept site: Body site vaccine  was administered
    :param CodeableConcept route: How vaccine entered body
    :param Quantity doseQuantity: Amount of vaccine administered
    :param Performer performer: Who performed event
    :param Annotation note: Additional immunization notes
    :param CodeableConcept reasonCode: Why immunization occurred
    :param Reference reasonReference: Why immunization occurred
    :param bool isSubpotent: Dose potency
    :param CodeableConcept subpotentReason: Reason for being subpotent
    :param Education education: Educational material presented to patient
    :param CodeableConcept programEligibility: Patient eligibility for a vaccination program
    :param CodeableConcept fundingSource: Funding source for the vaccine
    :param Reaction reaction: Details of a reaction that follows immunization
    :param ProtocolApplied protocolApplied: Protocol followed by the provider
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "vaccineCode": {"class_name": "CodeableConcept", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "reportOrigin": {"class_name": "CodeableConcept", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "site": {"class_name": "CodeableConcept", "is_contained": False},
        "route": {"class_name": "CodeableConcept", "is_contained": False},
        "doseQuantity": {"class_name": "Quantity", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "subpotentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "education": {"class_name": "Education", "is_contained": True},
        "programEligibility": {"class_name": "CodeableConcept", "is_contained": False},
        "fundingSource": {"class_name": "CodeableConcept", "is_contained": False},
        "reaction": {"class_name": "Reaction", "is_contained": True},
        "protocolApplied": {"class_name": "ProtocolApplied", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        vaccineCode: "CodeableConcept" = None,
        patient: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrenceString: "str" = None,
        recorded: "str" = None,
        primarySource: "bool" = None,
        reportOrigin: "CodeableConcept" = None,
        location: "Reference" = None,
        manufacturer: "Reference" = None,
        lotNumber: "str" = None,
        expirationDate: "str" = None,
        site: "CodeableConcept" = None,
        route: "CodeableConcept" = None,
        doseQuantity: "Quantity" = None,
        performer: list["Performer"] = None,
        note: list["Annotation"] = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        isSubpotent: "bool" = None,
        subpotentReason: list["CodeableConcept"] = None,
        education: list["Education"] = None,
        programEligibility: list["CodeableConcept"] = None,
        fundingSource: "CodeableConcept" = None,
        reaction: list["Reaction"] = None,
        protocolApplied: list["ProtocolApplied"] = None,
    ):

        self.resourceType = "Immunization"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.statusReason = statusReason
        self.vaccineCode = vaccineCode
        self.patient = patient
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrenceString = occurrenceString
        self.recorded = recorded
        self.primarySource = primarySource
        self.reportOrigin = reportOrigin
        self.location = location
        self.manufacturer = manufacturer
        self.lotNumber = lotNumber
        self.expirationDate = expirationDate
        self.site = site
        self.route = route
        self.doseQuantity = doseQuantity
        self.performer = performer or []
        self.note = note or []
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.isSubpotent = isSubpotent
        self.subpotentReason = subpotentReason or []
        self.education = education or []
        self.programEligibility = programEligibility or []
        self.fundingSource = fundingSource
        self.reaction = reaction or []
        self.protocolApplied = protocolApplied or []

    @classmethod
    def from_dict(cls, data: dict) -> "Immunization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Immunization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceSourceMaterial. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Resource import *


class FractionDescription(FhirBaseModel):
    """Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str fraction: This element is capturing information about the fraction of a plant part, or human plasma for fractionation
    :param CodeableConcept materialType: The specific type of the material constituting the component. For Herbal preparations the particulars of the extracts (liquid/dry) is described in Specified Substance Group 1
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "materialType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        fraction: "str" = None,
        materialType: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.fraction = fraction
        self.materialType = materialType

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Author(FhirBaseModel):
    """4.9.13.6.1 Author type (Conditional).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept authorType: The type of author of an organism species shall be specified. The parenthetical author of an organism species refers to the first author who published the plant/animal name (of any rank). The primary author of an organism species refers to the first author(s), who validly published the plant/animal name
    :param str authorDescription: The author of an organism species shall be specified. The author year of an organism shall also be specified when applicable; refers to the year in which the first author(s) published the infraspecific plant/animal name (of any rank)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "authorType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        authorType: "CodeableConcept" = None,
        authorDescription: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.authorType = authorType
        self.authorDescription = authorDescription

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Hybrid(FhirBaseModel):
    """4.9.13.8.1 Hybrid species maternal organism ID (Optional).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str maternalOrganismId: The identifier of the maternal species constituting the hybrid organism shall be specified based on a controlled vocabulary. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal
    :param str maternalOrganismName: The name of the maternal species constituting the hybrid organism shall be specified. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal
    :param str paternalOrganismId: The identifier of the paternal species constituting the hybrid organism shall be specified based on a controlled vocabulary
    :param str paternalOrganismName: The name of the paternal species constituting the hybrid organism shall be specified
    :param CodeableConcept hybridType: The hybrid type of an organism shall be specified
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "hybridType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        maternalOrganismId: "str" = None,
        maternalOrganismName: "str" = None,
        paternalOrganismId: "str" = None,
        paternalOrganismName: "str" = None,
        hybridType: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.maternalOrganismId = maternalOrganismId
        self.maternalOrganismName = maternalOrganismName
        self.paternalOrganismId = paternalOrganismId
        self.paternalOrganismName = paternalOrganismName
        self.hybridType = hybridType

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class OrganismGeneral(FhirBaseModel):
    """4.9.13.7.1 Kingdom (Conditional).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept kingdom: The kingdom of an organism shall be specified
    :param CodeableConcept phylum: The phylum of an organism shall be specified
    :param CodeableConcept _class: The class of an organism shall be specified
    :param CodeableConcept order: The order of an organism shall be specified,
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "kingdom": {"class_name": "CodeableConcept", "is_contained": False},
        "phylum": {"class_name": "CodeableConcept", "is_contained": False},
        "_class": {"class_name": "CodeableConcept", "is_contained": False},
        "order": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        kingdom: "CodeableConcept" = None,
        phylum: "CodeableConcept" = None,
        _class: "CodeableConcept" = None,
        order: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.kingdom = kingdom
        self.phylum = phylum
        self._class = _class
        self.order = order

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Organism(FhirBaseModel):
    """This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.:param Identifier organismId: The unique identifier associated with the source material parent organism shall be specified
    :param str organismName: The organism accepted Scientific name shall be provided based on the organism taxonomy
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept family: The family of an organism shall be specified
    :param CodeableConcept genus: The genus of an organism shall be specified; refers to the Latin epithet of the genus element of the plant/animal scientific name; it is present in names for genera, species and infraspecies
    :param CodeableConcept species: The species of an organism shall be specified; refers to the Latin epithet of the species of the plant/animal; it is present in names for species and infraspecies
    :param CodeableConcept intraspecificType: The Intraspecific type of an organism shall be specified
    :param str intraspecificDescription: The intraspecific description of an organism shall be specified based on a controlled vocabulary. For Influenza Vaccine, the intraspecific description shall contain the syntax of the antigen in line with the WHO convention
    :param Author author: 4.9.13.6.1 Author type (Conditional)
    :param Hybrid hybrid: 4.9.13.8.1 Hybrid species maternal organism ID (Optional)
    :param OrganismGeneral organismGeneral: 4.9.13.7.1 Kingdom (Conditional)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "organismId": {"class_name": "Identifier", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "family": {"class_name": "CodeableConcept", "is_contained": False},
        "genus": {"class_name": "CodeableConcept", "is_contained": False},
        "species": {"class_name": "CodeableConcept", "is_contained": False},
        "intraspecificType": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "Author", "is_contained": True},
        "hybrid": {"class_name": "Hybrid", "is_contained": True},
        "organismGeneral": {"class_name": "OrganismGeneral", "is_contained": True},
    }

    def __init__(
        self,
        organismId: "Identifier" = None,
        organismName: "str" = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        family: "CodeableConcept" = None,
        genus: "CodeableConcept" = None,
        species: "CodeableConcept" = None,
        intraspecificType: "CodeableConcept" = None,
        intraspecificDescription: "str" = None,
        author: list["Author"] = None,
        hybrid: "Hybrid" = None,
        organismGeneral: "OrganismGeneral" = None,
    ):
        self.organismId = organismId
        self.organismName = organismName
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.family = family
        self.genus = genus
        self.species = species
        self.intraspecificType = intraspecificType
        self.intraspecificDescription = intraspecificDescription
        self.author = author or []
        self.hybrid = hybrid
        self.organismGeneral = organismGeneral

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PartDescription(FhirBaseModel):
    """To do.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept part: Entity of anatomical origin of source material within an organism
    :param CodeableConcept partLocation: The detailed anatomic location when the part can be extracted from different anatomical locations of the organism. Multiple alternative locations may apply
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "part": {"class_name": "CodeableConcept", "is_contained": False},
        "partLocation": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        part: "CodeableConcept" = None,
        partLocation: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.part = part
        self.partLocation = partLocation

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceSourceMaterial(DomainResource):
    """Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept sourceMaterialClass: General high level classification of the source material specific to the origin of the material
    :param CodeableConcept sourceMaterialType: The type of the source material shall be specified based on a controlled vocabulary. For vaccines, this subclause refers to the class of infectious agent
    :param CodeableConcept sourceMaterialState: The state of the source material when extracted
    :param Identifier organismId: The unique identifier associated with the source material parent organism shall be specified
    :param str organismName: The organism accepted Scientific name shall be provided based on the organism taxonomy
    :param Identifier parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant)
    :param str parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation
    :param CodeableConcept countryOfOrigin: The country where the plant material is harvested or the countries where the plasma is sourced from as laid down in accordance with the Plasma Master File. For “Plasma-derived substances” the attribute country of origin provides information about the countries used for the manufacturing of the Cryopoor plama or Crioprecipitate
    :param str geographicalLocation: The place/region where the plant is harvested or the places/regions where the animal source material has its habitat
    :param CodeableConcept developmentStage: Stage of life for animals, plants, insects and microorganisms. This information shall be provided only when the substance is significantly different in these stages (e.g. foetal bovine serum)
    :param FractionDescription fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels
    :param Organism organism: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf
    :param PartDescription partDescription: To do
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sourceMaterialClass": {"class_name": "CodeableConcept", "is_contained": False},
        "sourceMaterialType": {"class_name": "CodeableConcept", "is_contained": False},
        "sourceMaterialState": {"class_name": "CodeableConcept", "is_contained": False},
        "organismId": {"class_name": "Identifier", "is_contained": False},
        "parentSubstanceId": {"class_name": "Identifier", "is_contained": False},
        "countryOfOrigin": {"class_name": "CodeableConcept", "is_contained": False},
        "developmentStage": {"class_name": "CodeableConcept", "is_contained": False},
        "fractionDescription": {
            "class_name": "FractionDescription",
            "is_contained": True,
        },
        "organism": {"class_name": "Organism", "is_contained": True},
        "partDescription": {"class_name": "PartDescription", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sourceMaterialClass: "CodeableConcept" = None,
        sourceMaterialType: "CodeableConcept" = None,
        sourceMaterialState: "CodeableConcept" = None,
        organismId: "Identifier" = None,
        organismName: "str" = None,
        parentSubstanceId: list["Identifier"] = None,
        parentSubstanceName: list["str"] = None,
        countryOfOrigin: list["CodeableConcept"] = None,
        geographicalLocation: list["str"] = None,
        developmentStage: "CodeableConcept" = None,
        fractionDescription: list["FractionDescription"] = None,
        organism: "Organism" = None,
        partDescription: list["PartDescription"] = None,
    ):

        self.resourceType = "SubstanceSourceMaterial"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sourceMaterialClass = sourceMaterialClass
        self.sourceMaterialType = sourceMaterialType
        self.sourceMaterialState = sourceMaterialState
        self.organismId = organismId
        self.organismName = organismName
        self.parentSubstanceId = parentSubstanceId or []
        self.parentSubstanceName = parentSubstanceName or []
        self.countryOfOrigin = countryOfOrigin or []
        self.geographicalLocation = geographicalLocation or []
        self.developmentStage = developmentStage
        self.fractionDescription = fractionDescription or []
        self.organism = organism
        self.partDescription = partDescription or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceSourceMaterial":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceSourceMaterial":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Schedule. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Schedule(DomainResource):
    """A container for slots of time that may be available for booking appointments.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this item
    :param bool active: Whether this schedule is in active use
    :param CodeableConcept serviceCategory: High-level category
    :param CodeableConcept serviceType: Specific service
    :param CodeableConcept specialty: Type of specialty needed
    :param Reference actor: Resource(s) that availability information is being provided for
    :param Period planningHorizon: Period of time covered by schedule
    :param str comment: Comments on availability
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "serviceCategory": {"class_name": "CodeableConcept", "is_contained": False},
        "serviceType": {"class_name": "CodeableConcept", "is_contained": False},
        "specialty": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
        "planningHorizon": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        serviceCategory: list["CodeableConcept"] = None,
        serviceType: list["CodeableConcept"] = None,
        specialty: list["CodeableConcept"] = None,
        actor: list["Reference"] = None,
        planningHorizon: "Period" = None,
        comment: "str" = None,
    ):

        self.resourceType = "Schedule"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.serviceCategory = serviceCategory or []
        self.serviceType = serviceType or []
        self.specialty = specialty or []
        self.actor = actor or []
        self.planningHorizon = planningHorizon
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "Schedule":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Schedule":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for List. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Entry(FhirBaseModel):
    """Entries in this list.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept flag: Status/Workflow information about this item
    :param bool deleted: If this item is actually marked as deleted
    :param str date: When item added to list
    :param Reference item: Actual entry
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "flag": {"class_name": "CodeableConcept", "is_contained": False},
        "item": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        flag: "CodeableConcept" = None,
        deleted: "bool" = None,
        date: "str" = None,
        item: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.flag = flag
        self.deleted = deleted
        self.date = date
        self.item = item

    @classmethod
    def from_dict(cls, data: dict) -> "List":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "List":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class List(DomainResource):
    """A list is a curated collection of resources.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier
    :param str status: current | retired | entered-in-error
    :param str mode: working | snapshot | changes
    :param str title: Descriptive name for the list
    :param CodeableConcept code: What the purpose of this list is
    :param Reference subject: If all resources have the same subject
    :param Reference encounter: Context in which list created
    :param str date: When the list was prepared
    :param Reference source: Who and/or what defined the list contents (aka Author)
    :param CodeableConcept orderedBy: What order the list has
    :param Annotation note: Comments about the list
    :param Entry entry: Entries in the list
    :param CodeableConcept emptyReason: Why list is empty
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
        "orderedBy": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "entry": {"class_name": "Entry", "is_contained": True},
        "emptyReason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        mode: "str" = None,
        title: "str" = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        date: "str" = None,
        source: "Reference" = None,
        orderedBy: "CodeableConcept" = None,
        note: list["Annotation"] = None,
        entry: list["Entry"] = None,
        emptyReason: "CodeableConcept" = None,
    ):

        self.resourceType = "List"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.mode = mode
        self.title = title
        self.code = code
        self.subject = subject
        self.encounter = encounter
        self.date = date
        self.source = source
        self.orderedBy = orderedBy
        self.note = note or []
        self.entry = entry or []
        self.emptyReason = emptyReason

    @classmethod
    def from_dict(cls, data: dict) -> "List":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "List":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for GraphDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Node(FhirBaseModel):
    """Potential target for the link.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str nodeId: Internal ID - target for link references
    :param str description: Why this node is specified
    :param str type: Type of resource this link refers to
    :param str profile: Profile for the target resource
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        nodeId: "str" = None,
        description: "str" = None,
        type: "str" = None,
        profile: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.nodeId = nodeId
        self.description = description
        self.type = type
        self.profile = profile

    @classmethod
    def from_dict(cls, data: dict) -> "GraphDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GraphDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Compartment(FhirBaseModel):
    """Compartment Consistency Rules.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str use: where | requires
    :param str rule: identical | matching | different | custom
    :param str code: Patient | Encounter | RelatedPerson | Practitioner | Device | EpisodeOfCare
    :param str expression: Custom rule, as a FHIRPath expression
    :param str description: Documentation for FHIRPath expression
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        use: "str" = None,
        rule: "str" = None,
        code: "str" = None,
        expression: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.use = use
        self.rule = rule
        self.code = code
        self.expression = expression
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "GraphDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GraphDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Link(FhirBaseModel):
    """Links this graph makes rules about.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Why this link is specified
    :param int min: Minimum occurrences for this link
    :param str max: Maximum occurrences for this link
    :param str sourceId: Source Node for this link
    :param str path: Path in the resource that contains the link
    :param str sliceName: Which slice (if profiled)
    :param str targetId: Target Node for this link
    :param str params: Criteria for reverse lookup
    :param Compartment compartment: Compartment Consistency Rules
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "compartment": {"class_name": "Compartment", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        min: "int" = None,
        max: "str" = None,
        sourceId: "str" = None,
        path: "str" = None,
        sliceName: "str" = None,
        targetId: "str" = None,
        params: "str" = None,
        compartment: list["Compartment"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.min = min
        self.max = max
        self.sourceId = sourceId
        self.path = path
        self.sliceName = sliceName
        self.targetId = targetId
        self.params = params
        self.compartment = compartment or []

    @classmethod
    def from_dict(cls, data: dict) -> "GraphDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GraphDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class GraphDefinition(DomainResource):
    """A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this graph definition, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the GraphDefinition (business identifier)
    :param str version: Business version of the graph definition
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this graph definition (computer friendly)
    :param str title: Name for this graph definition (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the graph definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for graph definition (if applicable)
    :param str purpose: Why this graph definition is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str start: Starting Node
    :param Node node: Potential target for the link
    :param Link link: Links this graph makes rules about
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "node": {"class_name": "Node", "is_contained": True},
        "link": {"class_name": "Link", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        start: "str" = None,
        node: list["Node"] = None,
        link: list["Link"] = None,
    ):

        self.resourceType = "GraphDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.start = start
        self.node = node or []
        self.link = link or []

    @classmethod
    def from_dict(cls, data: dict) -> "GraphDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GraphDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ManufacturedItemDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.MarketingStatus import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Property(FhirBaseModel):
    """General characteristics of this item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of characteristic
    :param CodeableConcept valueCodeableConcept: A value for the characteristic
    :param Quantity valueQuantity: A value for the characteristic
    :param str valueDate: A value for the characteristic
    :param bool valueBoolean: A value for the characteristic
    :param str valueMarkdown: A value for the characteristic
    :param Attachment valueAttachment: A value for the characteristic
    :param Reference valueReference: A value for the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueMarkdown: "str" = None,
        valueAttachment: "Attachment" = None,
        valueReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueMarkdown = valueMarkdown
        self.valueAttachment = valueAttachment
        self.valueReference = valueReference

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Constituent(FhirBaseModel):
    """A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity amount: The measurable amount of the substance, expressable in different ways (e.g. by mass or volume)
    :param CodeableConcept location: The physical location of the constituent/ingredient within the component
    :param CodeableConcept function: The function of this constituent within the component e.g. binder
    :param CodeableReference hasIngredient: The ingredient that is the constituent of the given component
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
        "location": {"class_name": "CodeableConcept", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "hasIngredient": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        amount: list["Quantity"] = None,
        location: list["CodeableConcept"] = None,
        function: list["CodeableConcept"] = None,
        hasIngredient: list["CodeableReference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.amount = amount or []
        self.location = location or []
        self.function = function or []
        self.hasIngredient = hasIngredient or []

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Component(FhirBaseModel):
    """Physical parts of the manufactured item, that it is intrisically made from. This is distinct from the ingredients that are part of its chemical makeup.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Defining type of the component e.g. shell, layer, ink
    :param CodeableConcept function: The function of this component within the item e.g. delivers active ingredient, masks taste
    :param Quantity amount: The measurable amount of total quantity of all substances in the component, expressable in different ways (e.g. by mass or volume)
    :param Constituent constituent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient)
    :param Property property: General characteristics of this component
    :param Component component: A component that this component contains or is made from
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
        "constituent": {"class_name": "Constituent", "is_contained": True},
        "property": {"class_name": "Property", "is_contained": True},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        function: list["CodeableConcept"] = None,
        amount: list["Quantity"] = None,
        constituent: list["Constituent"] = None,
        property: list["Property"] = None,
        component: list["Component"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.function = function or []
        self.amount = amount or []
        self.constituent = constituent or []
        self.property = property or []
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ManufacturedItemDefinition(DomainResource):
    """The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier
    :param str status: draft | active | retired | unknown
    :param str name: A descriptive name applied to this item
    :param CodeableConcept manufacturedDoseForm: Dose form as manufactured (before any necessary transformation)
    :param CodeableConcept unitOfPresentation: The “real-world” units in which the quantity of the item is described
    :param Reference manufacturer: Manufacturer of the item, one of several possible
    :param MarketingStatus marketingStatus: Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated
    :param CodeableConcept ingredient: The ingredients of this manufactured item. Only needed if these are not specified by incoming references from the Ingredient resource
    :param Property property: General characteristics of this item
    :param Component component: Physical parts of the manufactured item, that it is intrisically made from. This is distinct from the ingredients that are part of its chemical makeup
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "manufacturedDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "unitOfPresentation": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "marketingStatus": {"class_name": "MarketingStatus", "is_contained": False},
        "ingredient": {"class_name": "CodeableConcept", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        name: "str" = None,
        manufacturedDoseForm: "CodeableConcept" = None,
        unitOfPresentation: "CodeableConcept" = None,
        manufacturer: list["Reference"] = None,
        marketingStatus: list["MarketingStatus"] = None,
        ingredient: list["CodeableConcept"] = None,
        property: list["Property"] = None,
        component: list["Component"] = None,
    ):

        self.resourceType = "ManufacturedItemDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.name = name
        self.manufacturedDoseForm = manufacturedDoseForm
        self.unitOfPresentation = unitOfPresentation
        self.manufacturer = manufacturer or []
        self.marketingStatus = marketingStatus or []
        self.ingredient = ingredient or []
        self.property = property or []
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "ManufacturedItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ManufacturedItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationKnowledge. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Dosage import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Money import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class RelatedMedicationKnowledge(FhirBaseModel):
    """Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Category of medicationKnowledge
    :param Reference reference: Associated documentation about the associated medication knowledge
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        reference: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.reference = reference or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Monograph(FhirBaseModel):
    """Associated documentation about the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The category of medication document
    :param Reference source: Associated documentation about the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        source: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.source = source

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Cost(FhirBaseModel):
    """The price of the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Period effectiveDate: The date range for which the cost is effective
    :param CodeableConcept type: The category of the cost information
    :param str source: The source or owner for the price information
    :param Money costMoney: The price or category of the cost of the medication
    :param CodeableConcept costCodeableConcept: The price or category of the cost of the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "effectiveDate": {"class_name": "Period", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "costMoney": {"class_name": "Money", "is_contained": False},
        "costCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        effectiveDate: list["Period"] = None,
        type: "CodeableConcept" = None,
        source: "str" = None,
        costMoney: "Money" = None,
        costCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.effectiveDate = effectiveDate or []
        self.type = type
        self.source = source
        self.costMoney = costMoney
        self.costCodeableConcept = costCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MonitoringProgram(FhirBaseModel):
    """The program under which the medication is reviewed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of program under which the medication is monitored
    :param str name: Name of the reviewing program
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        name: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.name = name

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dosage(FhirBaseModel):
    """Dosage for the medication for the specific guidelines.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Category of dosage for a medication
    :param Dosage dosage: Dosage for the medication for the specific guidelines
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        dosage: list["Dosage"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.dosage = dosage or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PatientCharacteristic(FhirBaseModel):
    """Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Categorization of specific characteristic that is relevant to the administration guideline
    :param CodeableConcept valueCodeableConcept: The specific characteristic
    :param Quantity valueQuantity: The specific characteristic
    :param Range valueRange: The specific characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DosingGuideline(FhirBaseModel):
    """The guidelines for the dosage of the medication for the indication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept treatmentIntent: Intention of the treatment
    :param Dosage dosage: Dosage for the medication for the specific guidelines
    :param CodeableConcept administrationTreatment: Type of treatment the guideline applies to
    :param PatientCharacteristic patientCharacteristic: Characteristics of the patient that are relevant to the administration guidelines
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "treatmentIntent": {"class_name": "CodeableConcept", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": True},
        "administrationTreatment": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "patientCharacteristic": {
            "class_name": "PatientCharacteristic",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        treatmentIntent: "CodeableConcept" = None,
        dosage: list["Dosage"] = None,
        administrationTreatment: "CodeableConcept" = None,
        patientCharacteristic: list["PatientCharacteristic"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.treatmentIntent = treatmentIntent
        self.dosage = dosage or []
        self.administrationTreatment = administrationTreatment
        self.patientCharacteristic = patientCharacteristic or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class IndicationGuideline(FhirBaseModel):
    """Guidelines or protocols that are applicable for the administration of the medication based on indication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference indication: Indication for use that applies to the specific administration guideline
    :param DosingGuideline dosingGuideline: Guidelines for dosage of the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "indication": {"class_name": "CodeableReference", "is_contained": False},
        "dosingGuideline": {"class_name": "DosingGuideline", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        indication: list["CodeableReference"] = None,
        dosingGuideline: list["DosingGuideline"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.indication = indication or []
        self.dosingGuideline = dosingGuideline or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicineClassification(FhirBaseModel):
    """Categorization of the medication within a formulary or classification system.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of category for the medication (for example, therapeutic classification, therapeutic sub-classification)
    :param str sourceString: The source of the classification
    :param str sourceUri: The source of the classification
    :param CodeableConcept classification: Specific category assigned to the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        sourceString: "str" = None,
        sourceUri: "str" = None,
        classification: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.sourceString = sourceString
        self.sourceUri = sourceUri
        self.classification = classification or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Packaging(FhirBaseModel):
    """Information that only applies to packages (not products).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Cost cost: Cost of the packaged medication
    :param Reference packagedProduct: The packaged medication that is being priced
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "cost": {"class_name": "Cost", "is_contained": True},
        "packagedProduct": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        cost: list["Cost"] = None,
        packagedProduct: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.cost = cost or []
        self.packagedProduct = packagedProduct

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EnvironmentalSetting(FhirBaseModel):
    """Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Categorization of the setting
    :param Quantity valueQuantity: Value of the setting
    :param Range valueRange: Value of the setting
    :param CodeableConcept valueCodeableConcept: Value of the setting
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueCodeableConcept = valueCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StorageGuideline(FhirBaseModel):
    """Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str reference: Reference to additional information
    :param Annotation note: Additional storage notes
    :param Duration stabilityDuration: Duration remains stable
    :param EnvironmentalSetting environmentalSetting: Setting or value of environment for adequate storage
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "stabilityDuration": {"class_name": "Duration", "is_contained": False},
        "environmentalSetting": {
            "class_name": "EnvironmentalSetting",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: "str" = None,
        note: list["Annotation"] = None,
        stabilityDuration: "Duration" = None,
        environmentalSetting: list["EnvironmentalSetting"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference
        self.note = note or []
        self.stabilityDuration = stabilityDuration
        self.environmentalSetting = environmentalSetting or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substitution(FhirBaseModel):
    """Specifies if changes are allowed when dispensing a medication from a regulatory perspective.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Specifies the type of substitution allowed
    :param bool allowed: Specifies if regulation allows for changes in the medication when dispensing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        allowed: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.allowed = allowed

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MaxDispense(FhirBaseModel):
    """The maximum number of units of the medication that can be dispensed in a period.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: The maximum number of units of the medication that can be dispensed
    :param Duration period: The period that applies to the maximum number of units
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "period": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        period: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Regulatory(FhirBaseModel):
    """Regulatory information about a medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference regulatoryAuthority: Specifies the authority of the regulation
    :param Substitution substitution: Specifies if changes are allowed when dispensing a medication from a regulatory perspective
    :param CodeableConcept schedule: Specifies the schedule of a medication in jurisdiction
    :param MaxDispense maxDispense: The maximum number of units of the medication that can be dispensed in a period
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "regulatoryAuthority": {"class_name": "Reference", "is_contained": False},
        "substitution": {"class_name": "Substitution", "is_contained": True},
        "schedule": {"class_name": "CodeableConcept", "is_contained": False},
        "maxDispense": {"class_name": "MaxDispense", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        regulatoryAuthority: "Reference" = None,
        substitution: list["Substitution"] = None,
        schedule: list["CodeableConcept"] = None,
        maxDispense: "MaxDispense" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.regulatoryAuthority = regulatoryAuthority
        self.substitution = substitution or []
        self.schedule = schedule or []
        self.maxDispense = maxDispense

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Ingredient(FhirBaseModel):
    """Identifies a particular constituent of interest in the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference item: Substances contained in the medication
    :param CodeableConcept type: A code that defines the type of ingredient, active, base, etc
    :param Ratio strengthRatio: Quantity of ingredient present
    :param CodeableConcept strengthCodeableConcept: Quantity of ingredient present
    :param Quantity strengthQuantity: Quantity of ingredient present
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "CodeableReference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "strengthRatio": {"class_name": "Ratio", "is_contained": False},
        "strengthCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "strengthQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        item: "CodeableReference" = None,
        type: "CodeableConcept" = None,
        strengthRatio: "Ratio" = None,
        strengthCodeableConcept: "CodeableConcept" = None,
        strengthQuantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.item = item
        self.type = type
        self.strengthRatio = strengthRatio
        self.strengthCodeableConcept = strengthCodeableConcept
        self.strengthQuantity = strengthQuantity

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DrugCharacteristic(FhirBaseModel):
    """Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Code specifying the type of characteristic of medication
    :param CodeableConcept valueCodeableConcept: Description of the characteristic
    :param str valueString: Description of the characteristic
    :param Quantity valueQuantity: Description of the characteristic
    :param str valueBase64Binary: Description of the characteristic
    :param Attachment valueAttachment: Description of the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueQuantity: "Quantity" = None,
        valueBase64Binary: "str" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueQuantity = valueQuantity
        self.valueBase64Binary = valueBase64Binary
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Definitional(FhirBaseModel):
    """Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference definition: Definitional resources that provide more information about this medication
    :param CodeableConcept doseForm: powder | tablets | capsule +
    :param CodeableConcept intendedRoute: The intended or approved route of administration
    :param Ingredient ingredient: Active or inactive ingredient
    :param DrugCharacteristic drugCharacteristic: Specifies descriptive properties of the medicine
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "definition": {"class_name": "Reference", "is_contained": False},
        "doseForm": {"class_name": "CodeableConcept", "is_contained": False},
        "intendedRoute": {"class_name": "CodeableConcept", "is_contained": False},
        "ingredient": {"class_name": "Ingredient", "is_contained": True},
        "drugCharacteristic": {
            "class_name": "DrugCharacteristic",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        definition: list["Reference"] = None,
        doseForm: "CodeableConcept" = None,
        intendedRoute: list["CodeableConcept"] = None,
        ingredient: list["Ingredient"] = None,
        drugCharacteristic: list["DrugCharacteristic"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.definition = definition or []
        self.doseForm = doseForm
        self.intendedRoute = intendedRoute or []
        self.ingredient = ingredient or []
        self.drugCharacteristic = drugCharacteristic or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationKnowledge(DomainResource):
    """Information about a medication that is used to support knowledge.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this medication
    :param CodeableConcept code: Code that identifies this medication
    :param str status: active | entered-in-error | inactive
    :param Reference author: Creator or owner of the knowledge or information about the medication
    :param CodeableConcept intendedJurisdiction: Codes that identify the different jurisdictions for which the information of this resource was created
    :param str name: A name associated with the medication being described
    :param RelatedMedicationKnowledge relatedMedicationKnowledge: Associated or related medication information
    :param Reference associatedMedication: The set of medication resources that are associated with this medication
    :param CodeableConcept productType: Category of the medication or product
    :param Monograph monograph: Associated documentation about the medication
    :param str preparationInstruction: The instructions for preparing the medication
    :param Cost cost: The pricing of the medication
    :param MonitoringProgram monitoringProgram: Program under which a medication is reviewed
    :param IndicationGuideline indicationGuideline: Guidelines or protocols for administration of the medication for an indication
    :param MedicineClassification medicineClassification: Categorization of the medication within a formulary or classification system
    :param Packaging packaging: Details about packaged medications
    :param Reference clinicalUseIssue: Potential clinical issue with or between medication(s)
    :param StorageGuideline storageGuideline: How the medication should be stored
    :param Regulatory regulatory: Regulatory information about a medication
    :param Definitional definitional: Minimal definition information about the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "intendedJurisdiction": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "relatedMedicationKnowledge": {
            "class_name": "RelatedMedicationKnowledge",
            "is_contained": True,
        },
        "associatedMedication": {"class_name": "Reference", "is_contained": False},
        "productType": {"class_name": "CodeableConcept", "is_contained": False},
        "monograph": {"class_name": "Monograph", "is_contained": True},
        "cost": {"class_name": "Cost", "is_contained": True},
        "monitoringProgram": {"class_name": "MonitoringProgram", "is_contained": True},
        "indicationGuideline": {
            "class_name": "IndicationGuideline",
            "is_contained": True,
        },
        "medicineClassification": {
            "class_name": "MedicineClassification",
            "is_contained": True,
        },
        "packaging": {"class_name": "Packaging", "is_contained": True},
        "clinicalUseIssue": {"class_name": "Reference", "is_contained": False},
        "storageGuideline": {"class_name": "StorageGuideline", "is_contained": True},
        "regulatory": {"class_name": "Regulatory", "is_contained": True},
        "definitional": {"class_name": "Definitional", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        code: "CodeableConcept" = None,
        status: "str" = None,
        author: "Reference" = None,
        intendedJurisdiction: list["CodeableConcept"] = None,
        name: list["str"] = None,
        relatedMedicationKnowledge: list["RelatedMedicationKnowledge"] = None,
        associatedMedication: list["Reference"] = None,
        productType: list["CodeableConcept"] = None,
        monograph: list["Monograph"] = None,
        preparationInstruction: "str" = None,
        cost: list["Cost"] = None,
        monitoringProgram: list["MonitoringProgram"] = None,
        indicationGuideline: list["IndicationGuideline"] = None,
        medicineClassification: list["MedicineClassification"] = None,
        packaging: list["Packaging"] = None,
        clinicalUseIssue: list["Reference"] = None,
        storageGuideline: list["StorageGuideline"] = None,
        regulatory: list["Regulatory"] = None,
        definitional: "Definitional" = None,
    ):

        self.resourceType = "MedicationKnowledge"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.code = code
        self.status = status
        self.author = author
        self.intendedJurisdiction = intendedJurisdiction or []
        self.name = name or []
        self.relatedMedicationKnowledge = relatedMedicationKnowledge or []
        self.associatedMedication = associatedMedication or []
        self.productType = productType or []
        self.monograph = monograph or []
        self.preparationInstruction = preparationInstruction
        self.cost = cost or []
        self.monitoringProgram = monitoringProgram or []
        self.indicationGuideline = indicationGuideline or []
        self.medicineClassification = medicineClassification or []
        self.packaging = packaging or []
        self.clinicalUseIssue = clinicalUseIssue or []
        self.storageGuideline = storageGuideline or []
        self.regulatory = regulatory or []
        self.definitional = definitional

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Goal. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Target(FhirBaseModel):
    """Indicates what should be done by when.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept measure: The parameter whose value is being tracked
    :param Quantity detailQuantity: The target value to be achieved
    :param Range detailRange: The target value to be achieved
    :param CodeableConcept detailCodeableConcept: The target value to be achieved
    :param str detailString: The target value to be achieved
    :param bool detailBoolean: The target value to be achieved
    :param int detailInteger: The target value to be achieved
    :param Ratio detailRatio: The target value to be achieved
    :param str dueDate: Reach goal on or before
    :param Duration dueDuration: Reach goal on or before
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "measure": {"class_name": "CodeableConcept", "is_contained": False},
        "detailQuantity": {"class_name": "Quantity", "is_contained": False},
        "detailRange": {"class_name": "Range", "is_contained": False},
        "detailCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "detailRatio": {"class_name": "Ratio", "is_contained": False},
        "dueDuration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        measure: "CodeableConcept" = None,
        detailQuantity: "Quantity" = None,
        detailRange: "Range" = None,
        detailCodeableConcept: "CodeableConcept" = None,
        detailString: "str" = None,
        detailBoolean: "bool" = None,
        detailInteger: "int" = None,
        detailRatio: "Ratio" = None,
        dueDate: "str" = None,
        dueDuration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.measure = measure
        self.detailQuantity = detailQuantity
        self.detailRange = detailRange
        self.detailCodeableConcept = detailCodeableConcept
        self.detailString = detailString
        self.detailBoolean = detailBoolean
        self.detailInteger = detailInteger
        self.detailRatio = detailRatio
        self.dueDate = dueDate
        self.dueDuration = dueDuration

    @classmethod
    def from_dict(cls, data: dict) -> "Goal":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Goal":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Goal(DomainResource):
    """Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this goal
    :param str lifecycleStatus: proposed | planned | accepted | active | on-hold | completed | cancelled | entered-in-error | rejected
    :param CodeableConcept achievementStatus: in-progress | improving | worsening | no-change | achieved | sustaining | not-achieved | no-progress | not-attainable
    :param CodeableConcept category: E.g. Treatment, dietary, behavioral, etc
    :param bool continuous: After meeting the goal, ongoing activity is needed to sustain the goal objective
    :param CodeableConcept priority: high-priority | medium-priority | low-priority
    :param CodeableConcept description: Code or text describing goal
    :param Reference subject: Who this goal is intended for
    :param str startDate: When goal pursuit begins
    :param CodeableConcept startCodeableConcept: When goal pursuit begins
    :param Target target: Target outcome for the goal
    :param str statusDate: When goal status took effect
    :param str statusReason: Reason for current status
    :param Reference source: Who's responsible for creating Goal?
    :param Reference addresses: Issues addressed by this goal
    :param Annotation note: Comments about the goal
    :param CodeableReference outcome: What result was achieved regarding the goal?
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "achievementStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "priority": {"class_name": "CodeableConcept", "is_contained": False},
        "description": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "startCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "target": {"class_name": "Target", "is_contained": True},
        "source": {"class_name": "Reference", "is_contained": False},
        "addresses": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "outcome": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        lifecycleStatus: "str" = None,
        achievementStatus: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        continuous: "bool" = None,
        priority: "CodeableConcept" = None,
        description: "CodeableConcept" = None,
        subject: "Reference" = None,
        startDate: "str" = None,
        startCodeableConcept: "CodeableConcept" = None,
        target: list["Target"] = None,
        statusDate: "str" = None,
        statusReason: "str" = None,
        source: "Reference" = None,
        addresses: list["Reference"] = None,
        note: list["Annotation"] = None,
        outcome: list["CodeableReference"] = None,
    ):

        self.resourceType = "Goal"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.lifecycleStatus = lifecycleStatus
        self.achievementStatus = achievementStatus
        self.category = category or []
        self.continuous = continuous
        self.priority = priority
        self.description = description
        self.subject = subject
        self.startDate = startDate
        self.startCodeableConcept = startCodeableConcept
        self.target = target or []
        self.statusDate = statusDate
        self.statusReason = statusReason
        self.source = source
        self.addresses = addresses or []
        self.note = note or []
        self.outcome = outcome or []

    @classmethod
    def from_dict(cls, data: dict) -> "Goal":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Goal":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for VirtualServiceDetail. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *


class VirtualServiceDetail(FhirBaseModel):
    """VirtualServiceDetail Type: Virtual Service Contact Details.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Coding channelType: Channel Type
    :param str addressUrl: Contact address/number
    :param str addressString: Contact address/number
    :param ContactPoint addressContactPoint: Contact address/number
    :param ExtendedContactDetail addressExtendedContactDetail: Contact address/number
    :param str additionalInfo: Address to see alternative connection details
    :param int maxParticipants: Maximum number of participants supported by the virtual service
    :param str sessionKey: Session Key required by the virtual service
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "channelType": {"class_name": "Coding", "is_contained": False},
        "addressContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "addressExtendedContactDetail": {
            "class_name": "ExtendedContactDetail",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        channelType: "Coding" = None,
        addressUrl: "str" = None,
        addressString: "str" = None,
        addressContactPoint: "ContactPoint" = None,
        addressExtendedContactDetail: "ExtendedContactDetail" = None,
        additionalInfo: list["str"] = None,
        maxParticipants: "int" = None,
        sessionKey: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.channelType = channelType
        self.addressUrl = addressUrl
        self.addressString = addressString
        self.addressContactPoint = addressContactPoint
        self.addressExtendedContactDetail = addressExtendedContactDetail
        self.additionalInfo = additionalInfo or []
        self.maxParticipants = maxParticipants
        self.sessionKey = sessionKey

    @classmethod
    def from_dict(cls, data: dict) -> "VirtualServiceDetail":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "VirtualServiceDetail":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
